orca r4533 - trunk/test/keystrokes/firefox



Author: joanied
Date: Thu Feb 12 22:07:50 2009
New Revision: 4533
URL: http://svn.gnome.org/viewvc/orca?rev=4533&view=rev

Log:
Modified a very slow loading test to force it to be reproducible.


Modified:
   trunk/test/keystrokes/firefox/dojo_bug_570566.py

Modified: trunk/test/keystrokes/firefox/dojo_bug_570566.py
==============================================================================
--- trunk/test/keystrokes/firefox/dojo_bug_570566.py	(original)
+++ trunk/test/keystrokes/firefox/dojo_bug_570566.py	Thu Feb 12 22:07:50 2009
@@ -29,13 +29,20 @@
 ########################################################################
 # Extra loading time.
 #
-sequence.append(PauseAction(7000))
+sequence.append(PauseAction(10000))
 
 ########################################################################
 # Shift+Tab to the toolbar. The buttons may vary based on what's in
 # the clipboard, so we won't have an assertion here.
 #
 sequence.append(KeyComboAction("<Shift>Tab"))
+sequence.append(PauseAction(5000))
+sequence.append(KeyComboAction("Tab"))
+sequence.append(PauseAction(5000))
+sequence.append(KeyComboAction("<Shift>Tab"))
+sequence.append(WaitForFocus(acc_role=pyatspi.ROLE_PUSH_BUTTON))
 
 ########################################################################
 # Up Arrow to the heading above, and continue Up Arrowing to the top of
@@ -45,21 +52,22 @@
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "1. Up Arrow", 
-    ["BUG? - Too verbose. We're treating the page as if it had just loaded.",
-     "BRAILLE LINE:  'Created from div h2'",
-     "     VISIBLE:  'Created from div h2', cursor=1",
-     "BRAILLE LINE:  'Editor Test'",
-     "     VISIBLE:  'Editor Test', cursor=0",
-     "BRAILLE LINE:  'Created from div h2'",
+    ["BRAILLE LINE:  'Created from div h2'",
      "     VISIBLE:  'Created from div h2', cursor=1",
-     "SPEECH OUTPUT: 'Created from div heading level 2 heading level 2'",
-     "SPEECH OUTPUT: 'Editor Test page'",
      "SPEECH OUTPUT: 'Created from div heading level 2 heading level 2'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "2. Up Arrow", 
+    ["BRAILLE LINE:  'Created from div h2'",
+     "     VISIBLE:  'Created from div h2', cursor=1",
+     "SPEECH OUTPUT: 'Created from div heading level 2'"]))
+
+sequence.append(utils.StartRecordingAction())
+sequence.append(KeyComboAction("Up"))
+sequence.append(utils.AssertPresentationAction(
+    "3. Up Arrow", 
     ["BRAILLE LINE:  'Editor + Plugins Test h1'",
      "     VISIBLE:  'Editor + Plugins Test h1', cursor=1",
      "SPEECH OUTPUT: 'Editor + Plugins Test heading level 1'"]))
@@ -67,7 +75,7 @@
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
-    "3. Up Arrow", 
+    "4. Up Arrow", 
     ["BUG? - The braille is not ideal, nor does it jive with the speech.",
      "BRAILLE LINE:  '<x> CheckBox<x> CheckBox<x> CheckBox<x> CheckBox<x> CheckBox'",
      "     VISIBLE:  '', cursor=1",
@@ -76,7 +84,7 @@
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
-    "4. Up Arrow", 
+    "5. Up Arrow", 
     ["BRAILLE LINE:  'Focus:<x> CheckBox Value:<x> CheckBox Change:<x> CheckBox Blur:<x> CheckBox Disabled:<x> CheckBox'",
      "     VISIBLE:  'Focus:<x> CheckBox Value:<x> Che', cursor=1",
      "SPEECH OUTPUT: 'Focus: check box checked grayed  Value: check box checked grayed  Change: check box checked grayed  Blur: check box checked grayed  Disabled: check box checked grayed  ",
@@ -85,7 +93,7 @@
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
-    "5. Up Arrow", 
+    "6. Up Arrow", 
     ["BRAILLE LINE:  'Automated Test - all check boxes should be checked'",
      "     VISIBLE:  'Automated Test - all check boxes', cursor=1",
      "SPEECH OUTPUT: 'Automated Test - all check boxes should be checked'"]))
@@ -29,13 +29,20 @@
 
 ########################################################################
-# Shift+Tab to the toolbar. The buttons may vary based on what's in
-# the clipboard, so we won't have an assertion here.
+# Give focus to the toolbar. The buttons may vary based on what's in
+# the clipboard, so we won't have an assertion here. The Tab and Shift
+# Tab is to force the page to finish loading. It sometimes seems to 
+# stall.
 #
 sequence.append(KeyComboAction("<Shift>Tab"))



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]